==> haskell-hoauth2-2.13.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.13.0
visibility:           public
id:                   hoauth2-2.13.0-4NE6HENo7jh3rH6kXs6HCS
key:                  hoauth2-2.13.0-4NE6HENo7jh3rH6kXs6HCS
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  28469217b3c85ae5daf266c8386d912f
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.13.0-4NE6HENo7jh3rH6kXs6HCS
depends:
    aeson-2.1.2.1-6h5MFvBT17H5yplsTy4ABm base-4.17.2.1
    base64-1.0-HLYaV7YvnXz76I81CIdYJE binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-3YH9347FRArGwqZdh3IBCs
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd exceptions-0.10.5
    http-conduit-2.3.9.1-9rm6EpSCOWt5nDJEmvqGWw
    http-types-0.12.4-8KsSLLTB3zVcsjL7f3kez
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt text-2.0.2
    transformers-0.5.6.2 uri-bytestring-0.3.3.1-KaRvJSJsp2L2GOri1lcvV4
    uri-bytestring-aeson-0.1.0.9-BuELoAEIripCUlIQI2RGUS

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hoauth2-2.13.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.13.0
visibility:           public
id:                   hoauth2-2.13.0-GSgVuVZjYkxG9P6iA4tcwe
key:                  hoauth2-2.13.0-GSgVuVZjYkxG9P6iA4tcwe
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  e7a23afa6c1e5c87c45d9e0f258a87e6
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hoauth2-2.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.13.0-GSgVuVZjYkxG9P6iA4tcwe
depends:
    aeson-2.1.2.1-9rGsBPhyshTKvPzkopJx8r base-4.17.2.1
    base64-1.0-J0oTLxy55BtDTG0iNODY7T binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-3OO0UiAuNvXForiLKNIyZt
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd exceptions-0.10.5
    http-conduit-2.3.9.1-7ptmt7HWTVU7WtzZcC0wnA
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt text-2.0.2
    transformers-0.5.6.2 uri-bytestring-0.3.3.1-4B4JBhnfLZ0FVT7oeq6NL4
    uri-bytestring-aeson-0.1.0.9-9Kq6q6TscEg85u5JJPj9zT

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
